@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // http://doc.spip.org/@action_editer_site_dist
 function action_editer_site_dist($arg=null) {
@@ -51,9 +51,11 @@ function action_editer_site_dist($arg=null) {
 			$id_syndic = insert_syndic(_request('id_parent'));
 			revisions_sites($id_syndic);
 			if ($logo = _request('logo')
-			 AND $format_logo = _request('format_logo'))
-				@rename($logo,
+			 AND $format_logo = _request('format_logo')){
+			 	include_spip('inc/distant');
+				@rename(copie_locale($logo),
 				_DIR_IMG . 'siteon'.$id_syndic.'.'.$format_logo);
+			 }
 	}
 	// Erreur
 	else {
