@@ -469,6 +469,8 @@ function corriger_extension($ext) {
 		return 'jpg';
 	case 'tiff':
 		return 'tif';
+	case 'aif':
+		return 'aiff';
 	case 'mpeg':
 		return 'mpg';
 	default:
