@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2011                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -16,6 +16,10 @@ if (!defined('_INC_DISTANT_VERSION_HTTP')) define('_INC_DISTANT_VERSION_HTTP', "
 if (!defined('_INC_DISTANT_CONTENT_ENCODING')) define('_INC_DISTANT_CONTENT_ENCODING', "gzip");
 if (!defined('_INC_DISTANT_USER_AGENT')) define('_INC_DISTANT_USER_AGENT', 'SPIP-' .$GLOBALS['spip_version_affichee']. " (" .$GLOBALS['home_server']. ")");
 
+define('_REGEXP_COPIE_LOCALE', ',' . 
+       preg_replace('@^https?:@', 'https?:', $GLOBALS['meta']['adresse_site'])
+       . "/?spip.php[?]action=acceder_document.*file=(.*)$,");
+
 //@define('_COPIE_LOCALE_MAX_SIZE',2097152); // poids (inc/utils l'a fait)
 //
 // Cree au besoin la copie locale d'un fichier distant
@@ -30,11 +34,9 @@ if (!defined('_INC_DISTANT_USER_AGENT')) define('_INC_DISTANT_USER_AGENT', 'SPIP
 // http://doc.spip.org/@copie_locale
 function copie_locale($source, $mode='auto') {
 
-	// si c'est la protection de soi-meme
-	$reg = ',' . $GLOBALS['meta']['adresse_site']
-	  . "/?spip.php[?]action=acceder_document.*file=(.*)$,";
-
-	if (preg_match($reg, $source, $local)) return substr(_DIR_IMG,strlen(_DIR_RACINE)) . urldecode($local[1]);
+	// si c'est la protection de soi-meme, retourner le path
+	if ($mode !== 'force' AND preg_match(_REGEXP_COPIE_LOCALE, $source, $local))
+		return substr(_DIR_IMG,strlen(_DIR_RACINE)) . urldecode($local[1]);
 
 	$local = fichier_copie_locale($source);
 	$localrac = _DIR_RACINE.$local;
@@ -404,8 +406,18 @@ function fichier_copie_locale($source) {
 		if (file_exists(_DIR_RACINE  . $f))
 		  return $f;
 	}
+
 	// Ping  pour voir si son extension est connue et autorisee
-	$path_parts = recuperer_infos_distantes($source,0,false) ;
+	// avec mise en cache du resultat du ping
+
+	$cache = sous_repertoire(_DIR_CACHE,'rid').md5($source);
+	if (!@file_exists($cache)
+	OR !$path_parts = @unserialize(spip_file_get_contents($cache))
+	OR _request('var_mode') == 'recalcul'
+	) {
+		$path_parts = recuperer_infos_distantes($source,0,false) ;
+		ecrire_fichier($cache, serialize($path_parts));
+	}
 	$ext = $path_parts ? $path_parts['extension'] : '';
 	if ($ext AND sql_getfetsel("extension", "spip_types_documents", "extension=".sql_quote($ext))) {
 		return nom_fichier_copie_locale($source, $ext);
@@ -602,7 +614,7 @@ function lance_requete($method, $scheme, $user, $host, $path, $port, $noproxy, $
 	if ($user) $user = urlencode($user[0]).":".urlencode($user[1]);
 
 	if ($http_proxy) {
-		$path = "$scheme://"
+		$path = (($scheme=='ssl') ? 'https://' : "$scheme://")
 			. (!$user ? '' : "$user@")
 			. "$host" . (($port != 80) ? ":$port" : "") . $path;
 		$t2 = @parse_url($http_proxy);
