@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // librairie pour parametrage plugin
 //
@@ -55,7 +55,7 @@ function liste_plugin_files($dir_plugins = null){
 	OR count($plugin_files[$dir_plugins]) == 0){
 		$plugin_files[$dir_plugins] = array();
 		foreach (preg_files($dir_plugins, '/plugin[.]xml$') as $plugin) {
-			$plugin_files[$dir_plugins][] = str_replace($dir_plugins,'',dirname($plugin));
+			$plugin_files[$dir_plugins][] = substr(dirname($plugin),strlen($dir_plugins));
 		}
 		sort($plugin_files[$dir_plugins]);
 
@@ -63,8 +63,8 @@ function liste_plugin_files($dir_plugins = null){
 		// supplementaires ; chemin calcule par rapport a _DIR_PLUGINS.
 		if (isset($dir_plugins_suppl)) {
 			foreach($dir_plugins_suppl as $suppl) {
-				foreach (preg_files($suppl, '/plugin[.]xml$') as $plugin) {
-					$plugin_files[$dir_plugins][] = (_DIR_RACINE ?'': '../') .dirname($plugin);
+				foreach (preg_files(_DIR_RACINE.$suppl, 'plugin[.]xml$') as $plugin) {
+					$plugin_files[$dir_plugins][] = (_DIR_RACINE? '':'../').dirname($plugin);
 				}
 			}
 		}
@@ -193,7 +193,7 @@ function liste_plugin_valides($liste_plug, $force = false){
 			// renseigner ce plugin
 			$infos[$dir_type][$plug] = $get_infos($plug,$force,constant($dir_type));
 			// si il n'y a pas d'erreur
-			if (!isset($infos[$dir_type][$plug]['erreur'])) {
+			if ($infos[$dir_type][$plug] AND !isset($infos[$dir_type][$plug]['erreur'])) {
 				// regarder si on a pas deja selectionne le meme plugin dans une autre version
 				$version = isset($infos[$dir_type][$plug]['version'])?$infos[$dir_type][$plug]['version']:NULL;
 				if (isset($liste_non_classee[$p=strtoupper($infos[$dir_type][$plug]['prefix'])])){
@@ -378,6 +378,9 @@ function ecrire_plugin_actifs($plugin,$pipe_recherche=false,$operation='raz') {
 	// generer les fichier
 	// charger_plugins_options.php
 	// charger_plugins_fonctions.php
+	if (defined('_DIR_PLUGINS_SUPPL'))
+		$dir_plugins_suppl = implode(array_filter(explode(':',_DIR_PLUGINS_SUPPL)),'|');
+
 	foreach(array('chemins'=>_CACHE_PLUGINS_PATH,'options'=>_CACHE_PLUGINS_OPT,'fonctions'=>_CACHE_PLUGINS_FCT) as $charge=>$fileconf){
 		$s = "";
 		$splugs = "";
@@ -385,12 +388,16 @@ function ecrire_plugin_actifs($plugin,$pipe_recherche=false,$operation='raz') {
 		if (is_array($infos)){
 			foreach($ordre as $p){
 				$dir_type = $plugin_valides[$p]['dir_type'];
-				$root_dir_type = str_replace('_DIR_','_ROOT_',$dir_type);
 				$plug = $plugin_valides[$p]['dir'];
-				$dir = $dir_type.".'"
-					. str_replace(constant($dir_type), '', $plug)
-					."/'";
 				$info = $infos[$dir_type][$plug];
+				if($dir_plugins_suppl && preg_match(',('.$dir_plugins_suppl.'),',$plugin_valides[$p]['dir'])){
+					//$plugin_valides[$p]['dir_type'] = '_DIR_RACINE';
+					$dir_type = '_DIR_RACINE';
+					//if(!test_espace_prive())
+						$plug = str_replace('../','',$plug);
+				}
+				$root_dir_type = str_replace('_DIR_','_ROOT_',$dir_type);
+				$dir = $dir_type.".'" . $plug ."/'";
 				// definir le plugin, donc le path avant l'include du fichier options
 				// permet de faire des include_spip pour attraper un inc_ du plugin
 				if ($charge=='chemins'){
@@ -415,9 +422,12 @@ function ecrire_plugin_actifs($plugin,$pipe_recherche=false,$operation='raz') {
 						// on genere un if file_exists devant chaque include pour pouvoir garder le meme niveau d'erreur general
 						$file = trim($file);
 
-						if (strpos($plug, constant($dir_type)) === 0) {
+						if (strlen(constant($dir_type)) && (strpos($plug, constant($dir_type)) === 0)) {
 							$dir = str_replace("'".constant($dir_type), $root_dir_type.".'", "'$plug/'");
 						}
+						if($root_dir_type == '_ROOT_RACINE'){
+							$plug = str_replace('../','',$plug);
+						}
 						else
 							$dir = $root_dir_type.".'$plug/'";
 						$s .= "if (file_exists(\$f=$dir.'".trim($file)."')){ include_once \$f;}\n";
@@ -433,8 +443,8 @@ function ecrire_plugin_actifs($plugin,$pipe_recherche=false,$operation='raz') {
 			}
 		}
 		if ($charge=='options'){
-			$s .= "function boutons_plugins(){return unserialize('".str_replace("'","\'",serialize($liste_boutons))."');}\n";
-			$s .= "function onglets_plugins(){return unserialize('".str_replace("'","\'",serialize($liste_onglets))."');}\n";
+			$s .= "if (!function_exists('boutons_plugins')){function boutons_plugins(){return unserialize('".str_replace("'","\'",serialize($liste_boutons))."');}}\n";
+			$s .= "if (!function_exists('onglets_plugins')){function onglets_plugins(){return unserialize('".str_replace("'","\'",serialize($liste_onglets))."');}}\n";
 		}
 		ecrire_fichier($fileconf, $start_file . $splugs . $s . $end_file);
 	}
@@ -699,7 +709,7 @@ function installe_plugins($test = false){
 		$plug = $resume['dir'];
 		$dir_type = $resume['dir_type'];		
 		$infos = $get_infos($plug,false,constant($dir_type));
-		if (isset($infos['install'])){
+		if ($infos AND isset($infos['install'])){
 			if ($test) return true; // il y a des installations a faire
 			$ok = installe_un_plugin($plug,$infos,$dir_type);
 			// on peut enregistrer le chemin ici car il est mis a jour juste avant l'affichage
