@@ -103,6 +103,10 @@ function ajouter_session($auteur) {
 			time() + $duree
 			);
 		spip_log("ajoute session $fichier_session cookie $duree");
+
+		// purger au passage les vieux fichiers de session
+		supprimer_sessions(-1);
+
 		return $_COOKIE['spip_session'];
 	}
 }
@@ -147,7 +151,7 @@ function actualiser_sessions($auteur) {
 	$GLOBALS['visiteur_session'] = $sauve;
 
 	// si c'est le meme, rafraichir les valeurs
-	if ($auteur['id_auteur'] == $sauve['id_auteur'])
+	if (isset($sauve['id_auteur']) and $auteur['id_auteur'] == $sauve['id_auteur'])
 		verifier_session();
 }
 
