@@ -576,7 +576,9 @@ function corriger_typo($letexte, $lang='') {
 // Tableaux
 //
 
+define('_RACCOURCI_CAPTION', ',^\|\|([^|]*)(\|(.*))?$,sS');
 define('_RACCOURCI_TH_SPAN', '\s*(?:{{[^{}]+}}\s*)?|<');
+define('_RACCOURCI_THEAD', true);
 
 // http://doc.spip.org/@traiter_tableau
 function traiter_tableau($bloc) {
@@ -595,19 +597,17 @@ function traiter_tableau($bloc) {
 		$l ++;
 
 		// Gestion de la premiere ligne :
-		if ($l == 1) {
+		if (($l == 1) AND preg_match(_RACCOURCI_CAPTION, rtrim($ligne,'|'), $cap)) {
 		// - <caption> et summary dans la premiere ligne :
 		//   || caption | summary || (|summary est optionnel)
-			if (preg_match(',^\|\|([^|]*)(\|(.*))?$,sS', rtrim($ligne,'|'), $cap)) {
-				$l = 0;
-				if ($caption = trim($cap[1]))
-					$debut_table .= "<caption>".$caption."</caption>\n";
+			$l = 0;
+			if ($caption = trim($cap[1]))
+				$debut_table .= "<caption>".$caption."</caption>\n";
 				$summary = ' summary="'.entites_html(trim($cap[3])).'"';
-			}
-		// - <thead> sous la forme |{{titre}}|{{titre}}|
-		//   Attention thead oblige a avoir tbody
-			else if (preg_match($reg_line1,	$ligne)) {
-			  	preg_match_all('/\|([^|]*)/S', $ligne, $cols);
+		} else {
+		// - <th> sous la forme |{{titre}}|{{titre}}|
+			if (preg_match($reg_line1, $ligne)) {
+				preg_match_all('/\|([^|]*)/S', $ligne, $cols);
 				$ligne='';$cols= $cols[1];
 				$colspan=1;
 				for($c=count($cols)-1; $c>=0; $c--) {
@@ -615,7 +615,7 @@ function traiter_tableau($bloc) {
 					if($cols[$c]=='<') {
 					  $colspan++;
 					} else {
-					  if($colspan>1) {
+					  if ($colspan>1) {
 						$attr= " colspan='$colspan'";
 						$colspan=1;
 					  }
@@ -624,15 +624,9 @@ function traiter_tableau($bloc) {
 					  $ligne= "<th scope='col'$attr>$cols[$c]</th>$ligne";
 					}
 				}
-
-				$debut_table .= "<thead><tr class='row_first'>".
-					$ligne."</tr></thead>\n";
-				$l = 0;
-			}
-		}
-
-		// Sinon ligne normale
-		if ($l) {
+				$lignes[] = $ligne;
+		  } else {
+			// Sinon ligne normale
 			// Gerer les listes a puce dans les cellules
 			if (strpos($ligne,"\n-*")!==false OR strpos($ligne,"\n-#")!==false)
 				$ligne = traiter_listes($ligne);
@@ -643,6 +637,7 @@ function traiter_tableau($bloc) {
 			// tout mettre dans un tableau 2d
 			preg_match_all('/\|([^|]*)/S', $ligne, $cols);
 			$lignes[]= $cols[1];
+			}
 		}
 	}
 
@@ -660,6 +655,7 @@ function traiter_tableau($bloc) {
 	  $align = true;
 	  for ($j=0;$j<$k;$j++) $rowspans[$j][$i] = 1;
 	  for ($j=0;$j<$k;$j++) {
+	    if (!is_array($lignes[$j])) continue; // cas du th
 	    $cell = trim($lignes[$j][$i]);
 	    if (preg_match($reg_line_all, $cell)) {
 		if (!preg_match('/^\d+([.,]?)\d*$/', $cell, $r))
@@ -676,10 +672,14 @@ function traiter_tableau($bloc) {
 
 	for($l=count($lignes)-1; $l>=0; $l--) {
 		$cols= $lignes[$l];
-		$colspan=1;
-		$ligne='';
-
-		for($c=count($cols)-1; $c>=0; $c--) {
+		if (!is_array($cols)) {
+		  $class = 'first';
+		  $ligne = $cols;
+		} else {
+		  $ligne='';
+		  $colspan=1;
+		  $class = alterner($l+1, 'even', 'odd');
+		  for($c=count($cols)-1; $c>=0; $c--) {
 			$attr= $numeric[$c];
 			$cell = trim($cols[$c]);
 			if($cell=='<') {
@@ -698,17 +698,17 @@ function traiter_tableau($bloc) {
 			  }
 			  $ligne= "\n<td".$attr.'>'.$cols[$c].'</td>'.$ligne;
 			}
+		  }
 		}
-
-		// ligne complete
-		$class = alterner($l+1, 'even', 'odd');
 		$html = "<tr class='row_$class'>$ligne</tr>\n$html";
 	}
+	if (_RACCOURCI_THEAD
+	AND preg_match("@^(<tr class='row_first'.*?</tr>)(.*)$@s", $html, $m))
+		$html = "<thead>$m[1]</thead>\n<tbody>$m[2]</tbody>\n";
+
 	return "\n\n<table".$GLOBALS['class_spip_plus'].$summary.">\n"
 		. $debut_table
-		. "<tbody>\n"
 		. $html
-		. "</tbody>\n"
 		. "</table>\n\n";
 }
 
