@@ -24,7 +24,7 @@ include_spip('inc/cookie');
 // Determiner l'action demandee
 //
 
-$exec = _request('exec');
+$exec = (string)_request('exec');
 $reinstall = _request('reinstall')?_request('reinstall'):($exec=='install'?'oui':NULL);
 //
 // Les scripts d'insallation n'authentifient pas, forcement,
@@ -104,7 +104,10 @@ elseif (isset($GLOBALS['meta']["admin"])) {
 	}
 }
 // si nom pas plausible, prendre le script par defaut
-elseif (!preg_match(',^[a-z_][0-9a-z_]*$,i', $exec)) $exec = "accueil";
+elseif (!preg_match(',^[a-z_][0-9a-z_]*$,i', $exec)) {
+	$exec = "accueil";
+	set_request('exec', $exec);
+}
 
 // Verification des plugins
 // (ne pas interrompre une restauration ou un upgrade)
@@ -148,9 +151,10 @@ if ($var_f = _request('transformer_xml')) {
 	$exec = $var_f;
 }
 
-if ($var_f = tester_url_ecrire($exec))
-
+if ($var_f = tester_url_ecrire($exec)) {
+	$var_f = charger_fonction ($var_f);
 	$var_f(); // at last
+}
 else {
 // Rien de connu: rerouter vers exec=404 au lieu d'echouer
 // ce qui permet de laisser la main a un plugin
@@ -164,7 +168,4 @@ if ($debug) {
 	$GLOBALS['debug_objets'][$var_mode_affiche][$var_mode_objet . 'tout'] = ($var_mode_affiche== 'validation' ? $page['texte'] :"");
 	echo erreur_squelette();
 }
-if (isset($tableau_des_erreurs) AND count($tableau_des_erreurs) AND $affiche_boutons_admin)
-	echo affiche_erreurs_page($tableau_des_erreurs);
-
 ?>
