@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -741,6 +741,9 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 'jour_non_connu_nc' => 'nepoznato',
 
 // L
+'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
+'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
+'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
 'lien_ajout_destinataire' => 'Dodaj ovog primaoca',
 'lien_ajouter_auteur' => 'Dodaj ovog autora',
 'lien_ajouter_participant' => 'Dodaj ucesnika',
@@ -784,7 +787,7 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 'mois_non_connu' => 'nepoznato',
 
 // N
-'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Contenu', # NEW
@@ -795,19 +798,6 @@ Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim cla
 'onglet_proprietes' => 'Propri&eacute;t&eacute;s', # NEW
 'onglet_repartition_actuelle' => 'Aktuelno',
 'onglet_sous_rubriques' => 'Sous-rubriques', # NEW
-'ortho_ajouter_ce_mot' => 'Dodaj rijec u rijecnik',
-'ortho_aucune_suggestion' => 'Nije pronadjena ni jedna sugestija za ovu rijec.',
-'ortho_avis_privacy' => 'Provjera pravopisa je integrisana u SPIP. Svaki put kad aktivirate ovu funkciju, procitajte sljedeci odlomak:',
-'ortho_avis_privacy2' => 'Da bi se provjerio pravopis jednog teksta, ova stranica ce poslati listu rijeci na jedan od externih "pravopisnih servera", koji su vam pruzeni na  raspolaganje od strane raznih clanova SPIP komune. Rijeci ce  biti poslane u pogresnom rasporedu da bi vam osigurali minimum  sigurnosti. Ako su vasi podaci povjerljivi, ne aktivirajte ovu opciju (i odmah povucite vase informacije sa Web-a).',
-'ortho_ce_mot_connu' => 'Ova rijec je dio rijecnika stranice.',
-'ortho_dico_absent' => 'Nije pronadjen ni jedan rijecnik za ovaj jezik',
-'ortho_mode_demploi' => 'Rijeci koje nisu prepoznate, podvucene  su crvenom bojom. Mozete kliknuti na svaku rijec i izabrati  neku od prijedloga za ispravku.',
-'ortho_mots_a_corriger' => 'rijeci za ispraviti',
-'ortho_orthographe' => 'Pravopis',
-'ortho_supprimer_ce_mot' => 'Odstrani ovu rijec iz rijecnika',
-'ortho_trop_de_fautes' => 'Paznja: vas tekst sadrzi previse gresaka. Nijedna ispravka nije predlozena da bi se sprijecilo preopterecenje sistema.',
-'ortho_verif_impossible' => 'Sistem ne moze provjeriti pravopis ovog teksta.',
-'ortho_verifier' => 'Provjera pravopisa',
 
 // P
 'page_pas_proxy' => 'Cette page ne doit pas passer par le proxy', # NEW
