@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -768,6 +768,9 @@ i en farve, der angiver deres status:',
 'jour_non_connu_nc' => '&nbsp;',
 
 // L
+'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
+'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
+'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
 'lien_ajout_destinataire' => 'Tilf&oslash;j denne modtager',
 'lien_ajouter_auteur' => 'Tilf&oslash;j denne forfatter',
 'lien_ajouter_participant' => 'Tilf&oslash;j modtager',
@@ -811,7 +814,7 @@ i en farve, der angiver deres status:',
 'mois_non_connu' => 'ukendt',
 
 // N
-'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Contenu', # NEW
@@ -822,19 +825,6 @@ i en farve, der angiver deres status:',
 'onglet_proprietes' => 'Propri&eacute;t&eacute;s', # NEW
 'onglet_repartition_actuelle' => 'nu',
 'onglet_sous_rubriques' => 'Sous-rubriques', # NEW
-'ortho_ajouter_ce_mot' => 'Add this word to the dictionary', # NEW
-'ortho_aucune_suggestion' => 'No suggestion was found for this word.', # NEW
-'ortho_avis_privacy' => 'Spip contains a spell checker. However, before enabling it, please read the following paragraph carefully:', # NEW
-'ortho_avis_privacy2' => 'In order to check spelling  a text, the site will send the list of words to be checked to an external "spelling server", which people of the Spip community have made available. The words are mixed up before being sent in order to maintain some level of confidentiality. If you are concerned about your data, do not activate this option (and withdraw all your information from the web at once).', # NEW
-'ortho_ce_mot_connu' => 'This word is in the site\'s dictionary.', # NEW
-'ortho_dico_absent' => 'No dictionary was found for this language', # NEW
-'ortho_mode_demploi' => 'Urecognised words have been highlighted in red. Click on these words to see suggested corrections.', # NEW
-'ortho_mots_a_corriger' => 'words to correct', # NEW
-'ortho_orthographe' => 'Spelling', # NEW
-'ortho_supprimer_ce_mot' => 'Remove this word from the dictionary', # NEW
-'ortho_trop_de_fautes' => 'Your text contains too many mistakes! In order to avoid overloading the system, no corrections have been suggested.', # NEW
-'ortho_verif_impossible' => 'The system cannot check the spelling of this text.', # NEW
-'ortho_verifier' => 'Spell check', # NEW
 
 // P
 'page_pas_proxy' => 'Cette page ne doit pas passer par le proxy', # NEW
