@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -485,7 +485,7 @@ Ihr Status wird durch die Farbe ihres Symbols angezeigt (Redakteur = gelb; Admin
 'info_pas_de_forum' => 'kein Forum',
 'info_passe_trop_court' => 'Passwort zu kurz.',
 'info_passes_identiques' => 'Die zwei Passworte stimmen nicht &uuml;berein.',
-'info_pense_bete_ancien' => 'Ihre alten Merkzettel', # MODIF
+'info_pense_bete_ancien' => 'Ihre alten Merkzettel',
 'info_plus_cinq_car' => 'mehr als 5 Zeichen',
 'info_plus_cinq_car_2' => '(mehr als 5 Zeichen)',
 'info_plus_trois_car' => '(mehr als 3 Zeichen)',
@@ -750,6 +750,9 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'jour_non_connu_nc' => 'unbekannt',
 
 // L
+'ldap_correspondance' => 'Vererbung von Feld @champ@',
+'ldap_correspondance_1' => 'Vererbung des LDAP Felds',
+'ldap_correspondance_2' => 'Geben sie bitte f&uuml;r jedes der folgenden SPIP-Felder das entsprechende LDAP-Feld an. Leere Felder werden nicht genutzt, LDAP-Felder mit Leerzeichen oder Kommata trennen, um mehrere zu probieren. ',
 'lien_ajout_destinataire' => 'Empf&auml;nger hinzuf&uuml;gen',
 'lien_ajouter_auteur' => 'Autor hinzuf&uuml;gen',
 'lien_ajouter_participant' => 'Teilnehmer hinzuf&uuml;gen',
@@ -793,7 +796,7 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'mois_non_connu' => 'unbekannt',
 
 // N
-'nouvelles_versions' => 'Neue Versionen von SPIP sind verf&uuml;gbar',
+'nouvelle_version_spip' => 'SPIP Version @version@ ist verf&uuml;gbar.',
 
 // O
 'onglet_contenu' => 'Inhalt',
@@ -804,19 +807,6 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'onglet_proprietes' => 'Eigenschaften',
 'onglet_repartition_actuelle' => 'zur Zeit',
 'onglet_sous_rubriques' => 'Unterrubriken',
-'ortho_ajouter_ce_mot' => 'Wort zum W&ouml;rterbuch hinzuf&uuml;gen',
-'ortho_aucune_suggestion' => 'F&uuml;r dieses Wort wurde kein Vorschlag gefunden.',
-'ortho_avis_privacy' => 'SPIP hat eine integrierte Rechtschreibkorrektur. Vor dem Aktivieren lesen sie bitte diesen Text aufmerksam durch:',
-'ortho_avis_privacy2' => 'Damit die Rechtschreibung eines Texts &uuml;berpr&uuml;ft werden kann, schickt SPIP die Worte an &laquo;Orthographieserver&raquo;, die von Mitgliedern der SPIP-Gemeinde zur Verf&uuml;gung gestellt werden. Die Worte werden in zuf&auml;lliger Reihenfolge &uuml;bertragen, um ein Maximun an Vertraulichkeit zu erm&ouml;glichen. Wenn Ihnen diese Methode nicht sicher genug ist, verzichten sie bitte darauf, die Rechtschreibpr&uuml;fung zu aktivieren (und entfernen ihre Informationen sofort aus dem Internet).',
-'ortho_ce_mot_connu' => 'Dieses Wort steht im W&ouml;rterbuch der Website.',
-'ortho_dico_absent' => 'F&uuml;r diese Sprache wurde kein W&ouml;rterbuch gefunden.',
-'ortho_mode_demploi' => 'Nicht erkannte Worte sind rot markiert. Sie k&ouml;nnen auf jedes Wort klicken, um die Korrekturvorschl&auml;ge anzuzeigen.',
-'ortho_mots_a_corriger' => 'Zu korrigieren',
-'ortho_orthographe' => 'Orthographie',
-'ortho_supprimer_ce_mot' => 'Wort aus dem W&ouml;rerbuch l&ouml;schen',
-'ortho_trop_de_fautes' => 'Achtung: Ihr Text enth&auml;lt zu viele Fehler. Es wurden keine Korrekturvorschl&auml;ge gemacht, um das System nicht zu &uuml;berlasten.',
-'ortho_verif_impossible' => 'Das System kann die Rechtschreibung dieses Texts nicht pr&uuml;fen.',
-'ortho_verifier' => 'Rechtschreibung pr&uuml;fen',
 
 // P
 'page_pas_proxy' => 'Diese Seite darf nicht durch den Proxy &uuml;bertragen werden.',
