@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -775,6 +775,9 @@ La tradukoj estas kunligitaj al la originalo, kun koloro kiu indikas ties staton
 'jour_non_connu_nc' => 'ne konata',
 
 // L
+'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
+'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
+'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
 'lien_ajout_destinataire' => 'Aldoni tiun adresaton',
 'lien_ajouter_auteur' => 'Aldoni tiun a&#365;toron',
 'lien_ajouter_participant' => 'Aldoni partoprenanton',
@@ -818,7 +821,7 @@ La tradukoj estas kunligitaj al la originalo, kun koloro kiu indikas ties staton
 'mois_non_connu' => 'nekonata',
 
 // N
-'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Enhavo',
@@ -829,19 +832,6 @@ La tradukoj estas kunligitaj al la originalo, kun koloro kiu indikas ties staton
 'onglet_proprietes' => 'Trajtoj',
 'onglet_repartition_actuelle' => 'nun',
 'onglet_sous_rubriques' => 'Subrubrikoj',
-'ortho_ajouter_ce_mot' => 'Aldoni tiun vorton al la vortaro',
-'ortho_aucune_suggestion' => 'Neniu propono estis trovita por tiu vorto.',
-'ortho_avis_privacy' => 'SPIP enhavas ortografian kontrolilon. Tamen, anta&#365; ol aktivigi tiun funkcion, atente legu la jenan paragrafon&nbsp;:',
-'ortho_avis_privacy2' => 'Por kontroli la ortografion de teksto, la retejo sendas liston de kontrolotaj vortoj al eksteraj &laquo;&nbsp;ortografiaj serviloj&nbsp;&raquo;, kiujn disponigas al vi SPIP-anoj. Vortoj estas senditaj malorde por estigi minimuman konfidencon. Tamen, se vi timas pri via datenoj, ne aktivigu tiun elekton (kaj anka&#365; forigu tuj viajn datenoj el la reto).',
-'ortho_ce_mot_connu' => 'Tiu vorto trovi&#285;as en la vortaro de la retejo.',
-'ortho_dico_absent' => 'Neniu vortaro estis trovita por tiu lingvo',
-'ortho_mode_demploi' => 'Ne rekonitaj vortoj estas ru&#285;e substrekitaj. Vi povas musklaki &#265;iun vorton por afi&#349;i korekto-sugestojn.',
-'ortho_mots_a_corriger' => 'korektendaj vortoj',
-'ortho_orthographe' => 'Ortografio',
-'ortho_supprimer_ce_mot' => 'Forvi&#349;i tiun &#265;i vorton el la vortaro',
-'ortho_trop_de_fautes' => 'Atentu&nbsp;: via teksto enhavas tro da eraroj. Neniu korekto estas sugestita por ne super&#349;uti la sistemon.',
-'ortho_verif_impossible' => 'La sistemo ne povas kontroli la ortografion de tiu teksto.',
-'ortho_verifier' => 'Kontrolu la ortografion',
 
 // P
 'page_pas_proxy' => 'Tiu &#265;i pa&#285;o ne &#349;uti&#285;u tra la prokura servilo',
