@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -756,6 +756,9 @@ Itzulpenak originalari asoziatuta daude, bere egoera adierazten duten kolore bat
 'jour_non_connu_nc' => 'e.e.',
 
 // L
+'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
+'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
+'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
 'lien_ajout_destinataire' => 'Jasotzaile hau erantsi',
 'lien_ajouter_auteur' => 'Egile hau erantsi',
 'lien_ajouter_participant' => 'Parte-hartzaile bat erantsi',
@@ -799,7 +802,7 @@ Itzulpenak originalari asoziatuta daude, bere egoera adierazten duten kolore bat
 'mois_non_connu' => 'ezezagun',
 
 // N
-'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Edukia',
@@ -810,19 +813,6 @@ Itzulpenak originalari asoziatuta daude, bere egoera adierazten duten kolore bat
 'onglet_proprietes' => 'Proprietateak',
 'onglet_repartition_actuelle' => 'gaur egun',
 'onglet_sous_rubriques' => 'Azpi-eremuak',
-'ortho_ajouter_ce_mot' => 'Hitz hau hiztegira erantsi',
-'ortho_aucune_suggestion' => 'Ez da aurkitu proposamenik hitz honetarako.',
-'ortho_avis_privacy' => 'SPIP-ean ortografia-zuzentzaile bat txertatu da. Hala ere,funtzionalitate hau aktibatu ondoren, mesedez hurrengo paragrafoa arretaz irakurri :',
-'ortho_avis_privacy2' => 'Testu baten ortografia egiaztatzeko, guneak kontrolatzeko hitzen zerrenda bidaliko du SPIP komunitateko kide desberdinek zure eskura jarritako kanpoko ortografia-zerbitzarietako batera. Hitzak nahastuta bidaltzen dira konfidentzialtasun minimo bat ziurtatzeko. Zure datuengatik beldur bazara, ez aktibatu aukera hau (eta berehala zure datuak kendu Web-atik).',
-'ortho_ce_mot_connu' => 'Hitz hau guneko hiztegiaren parte da.',
-'ortho_dico_absent' => 'Ez da aurkitu hiztegirik hizkuntza honentzako',
-'ortho_mode_demploi' => 'Hitz ezezagunak gorrian azpimarratuta daude. Hitz bakoitzean klikatu ahal duzu zuzenketa-proposamenak erakusteko.',
-'ortho_mots_a_corriger' => 'zuzentzeko hitzak',
-'ortho_orthographe' => 'Ortografia',
-'ortho_supprimer_ce_mot' => 'Hitz hau kendu hiztegitik',
-'ortho_trop_de_fautes' => 'Erne : zure testuak akats gehiegi ditu, ez da proposatu zuzenketarik sistema gehiego ez kargatzeko.',
-'ortho_verif_impossible' => 'Sistemak ezin dutestu honetako ortografia egiaztatu.',
-'ortho_verifier' => 'Ortografia zuzendu',
 
 // P
 'page_pas_proxy' => 'Orri hau ez da proxy-tik pasa behar',
