@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -789,6 +789,9 @@ cunha cor que indica o seu estado&nbsp;:',
 'jour_non_connu_nc' => 'non consta',
 
 // L
+'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
+'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
+'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
 'lien_ajout_destinataire' => 'Engadir destinatari@',
 'lien_ajouter_auteur' => 'Engadir autor/a',
 'lien_ajouter_participant' => 'Engadir participante',
@@ -832,7 +835,7 @@ cunha cor que indica o seu estado&nbsp;:',
 'mois_non_connu' => 'desco&ntilde;ecido',
 
 // N
-'nouvelles_versions' => 'Est&aacute;n dispo&ntilde;&iacute;beis novas versi&oacute;ns de SPIP',
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Contido',
@@ -843,19 +846,6 @@ cunha cor que indica o seu estado&nbsp;:',
 'onglet_proprietes' => 'Propiedades',
 'onglet_repartition_actuelle' => 'actualmente',
 'onglet_sous_rubriques' => 'Subsecci&oacute;ns',
-'ortho_ajouter_ce_mot' => 'Engadir a palabra ao dicionario',
-'ortho_aucune_suggestion' => 'Non hai suxesti&oacute;n relacionada con este termo',
-'ortho_avis_privacy' => 'Un comprobador ortogr&aacute;fico foi integrado en SPIP. De todas maneiras, antes de o activar, lea con atenci&oacute;n o par&aacute;grafo seguinte&nbsp;:',
-'ortho_avis_privacy2' => 'Para comprobar a ortograf&iacute;a dun texto, o web vai enviar a lista de termos para comprobar a un dos &laquo;&nbsp;servidores d\'ortograf&iacute;a&nbsp;&raquo; externos que po&ntilde;en &aacute; s&uacute;a disposici&oacute;n varios membros da comunidade SPIP. As verbas son enviadas con desorde co fin de asegurar un m&iacute;nimo de confidencialidade. Se vostede ten reservas cos seus datos, non active esta opci&oacute;n (e retire todo dato persoal do web).',
-'ortho_ce_mot_connu' => 'Este termo est&aacute; recollido no dicionario do web',
-'ortho_dico_absent' => 'Non se atopou ning&uacute;n dicionario para esta  lingua',
-'ortho_mode_demploi' => 'Os termos non reco&ntilde;ecidos est&aacute;n subli&ntilde;ados en vermello. Pode premer sobre cada verba para ver suxesti&oacute;ns de correcci&oacute;n',
-'ortho_mots_a_corriger' => 'Termos para corrixir',
-'ortho_orthographe' => 'Ort&oacute;grafo',
-'ortho_supprimer_ce_mot' => 'Sacar este termo do dicionario',
-'ortho_trop_de_fautes' => 'Atenci&oacute;n&nbsp;: o seu texto cont&eacute;n demasiadas faltas, non se suxire ningunha correcci&oacute;n co fin de non sobrecargar o sistema.',
-'ortho_verif_impossible' => 'O sistema non pode comprobar a ortograf&iacute;a deste texto.',
-'ortho_verifier' => 'Comprobar a ortograf&iacute;a',
 
 // P
 'page_pas_proxy' => 'Esta p&aacute;xina non debe pasar por un proxy',
