@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -790,6 +790,9 @@ dalam warna yang menunjukkan statusnya:',
 'jour_non_connu_nc' => 'tidak dikenal',
 
 // L
+'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
+'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
+'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
 'lien_ajout_destinataire' => 'Tambahkan penerima ini',
 'lien_ajouter_auteur' => 'Tambahkan penulis ini',
 'lien_ajouter_participant' => 'Tambahkan seorang peserta',
@@ -833,7 +836,7 @@ dalam warna yang menunjukkan statusnya:',
 'mois_non_connu' => 'tidak dikenal',
 
 // N
-'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Contenu', # NEW
@@ -844,19 +847,6 @@ dalam warna yang menunjukkan statusnya:',
 'onglet_proprietes' => 'Propri&eacute;t&eacute;s', # NEW
 'onglet_repartition_actuelle' => 'sekarang',
 'onglet_sous_rubriques' => 'Sous-rubriques', # NEW
-'ortho_ajouter_ce_mot' => 'Tambahkan kata ini ke dalam kamus',
-'ortho_aucune_suggestion' => 'Tidak ada saran yang ditemukan untuk kata ini.',
-'ortho_avis_privacy' => 'SPIP memiliki pemeriksa ejaan. Walaupun demikian, sebelum mengaktifkannya, silakan baca paragraf berikut baik-baik:',
-'ortho_avis_privacy2' => 'Untuk memerikas ejaan sebuah teks, situs akan mengirimkan daftar kata-kata yang akan diperiksa ke server pengeja eksternal, yang telah disediakan oleh komunitas SPIP. Kata-kata akan dicampur sebelum dikirim guna menjaga tingkat kerahasiaan. Jika anda khawatir dengan data anda, jangan aktifkan opsi ini (dan tarik semua informasi anda dari web sekaligus).',
-'ortho_ce_mot_connu' => 'Kata ini terdapat di dalam kamus situs.',
-'ortho_dico_absent' => 'Tidak ada kamus ditemukan untuk bahasa ini',
-'ortho_mode_demploi' => 'Kata-kata yang tidak dikenal diberi tanda merah. Klik pada kata-kata tersebut untuk melihat koreksi yang disarankan.',
-'ortho_mots_a_corriger' => 'kata yang akan dikoreksi',
-'ortho_orthographe' => 'Ejaan',
-'ortho_supprimer_ce_mot' => 'Hapus kata ini dari kamus',
-'ortho_trop_de_fautes' => 'Teks anda mengandung banyak kesalahan! Agar sistem tidak terberati oleh kesalahan tersebut, tidak ada koreksi yang diberikan.',
-'ortho_verif_impossible' => 'Sistem tidak dapat memeriksa ejaan dari teks ini.',
-'ortho_verifier' => 'Pemeriksaan ejaan',
 
 // P
 'page_pas_proxy' => 'Cette page ne doit pas passer par le proxy', # NEW
