@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -789,6 +789,9 @@ Le traduzioni sono associate all\'originale,
 'jour_non_connu_nc' => 'n.c.',
 
 // L
+'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
+'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
+'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
 'lien_ajout_destinataire' => 'Aggiungi il destinatario',
 'lien_ajouter_auteur' => 'Aggiungi questa autrice',
 'lien_ajouter_participant' => 'Aggiungi una partecipante',
@@ -832,7 +835,7 @@ Le traduzioni sono associate all\'originale,
 'mois_non_connu' => 'sconosciuto',
 
 // N
-'nouvelles_versions' => 'De nouvelles versions de SPIP sont disponibles', # NEW
+'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW
 
 // O
 'onglet_contenu' => 'Contenuto',
@@ -843,19 +846,6 @@ Le traduzioni sono associate all\'originale,
 'onglet_proprietes' => 'Propriet&agrave;',
 'onglet_repartition_actuelle' => 'attualmente',
 'onglet_sous_rubriques' => 'Sotto-rubriche',
-'ortho_ajouter_ce_mot' => 'Aggiungere questa parola al dizionario',
-'ortho_aucune_suggestion' => 'Nessun suggerimento per questa parola.',
-'ortho_avis_privacy' => 'SPIP ha un controllo ortografico integrato. Prima di attivare questa funzionalit&agrave;, leggere attentamente quanto segue:',
-'ortho_avis_privacy2' => 'Per verificare l\'ortografia di un testo, il sito invier&agrave; la lista di parole da controllare a uno dei "server ortografici" esterni messi a disposizione al pubblico dai membri della comunit&agrave; SPIP. Le parole sono inviate in ordine casuale per rispettare la propriet&agrave; intellettuale degli autori. &Egrave; consigliabile disattivare tale funzionalit&agrave; se i testi trattati nel sito sono ritenuti troppo confidenziali (e magari si eviti di pubblicarli sul web...).',
-'ortho_ce_mot_connu' => 'Questa parola fa parte del dizionario del sito.',
-'ortho_dico_absent' => 'Nessun dizionario disponibile per questa lingua',
-'ortho_mode_demploi' => 'Le parole non riconosciute sono sottolineate in rosso. &Egrave; possibile cliccare su ogni parola per visualizzare eventuali suggerimenti per la correzione.',
-'ortho_mots_a_corriger' => 'parole da correggere',
-'ortho_orthographe' => 'Ortografia',
-'ortho_supprimer_ce_mot' => 'Eliminare questa parola dal dizionario',
-'ortho_trop_de_fautes' => 'Attenzione: il testo contiene troppi errori, non &egrave; stato fornito alcun suggerimento di correzione per evitare di sovraccaricare il sistema.',
-'ortho_verif_impossible' => 'Il sistema non pu&ograve; controllare l\'ortografia di questo testo.',
-'ortho_verifier' => 'Controllare l\'ortografia',
 
 // P
 'page_pas_proxy' => 'Questa pagina non deve passare attraverso il proxy',
