@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -647,7 +647,6 @@ Trugarez da gemer perzh
 'onglet_repartition_rubrique' => 'Dasparzh diouzh ar rummad',
 'onglet_save_restaur_base' => 'Savetei&ntilde;/Assevel an diaz',
 'onglet_vider_cache' => 'Goullonderi&ntilde; ar grubuilh',
-'ortho_trop_de_fautes2' => 'Klaskit reizha&ntilde; ar fazio&ugrave; brasa&ntilde; ha klaskit en-dro da c\'houde.',
 
 // P
 'pass_choix_pass' => 'Dibabit ho ker-tremen nevez :',
