@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -623,7 +623,6 @@ sera ignor&eacute;e) :
 'onglet_repartition_rubrique' => 'Distribucija po rubrikama',
 'onglet_save_restaur_base' => 'Backup/obnova baze podataka',
 'onglet_vider_cache' => 'Isprazni kes',
-'ortho_trop_de_fautes2' => 'Pocnite sa ispravljanjem ociglednih gresaka, zatim pokusajte ponovo.',
 
 // P
 'pass_choix_pass' => 'Izaberite vasu novu lozinku:',
