@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -68,7 +68,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'bouton_changer' => 'Canviar',
 'bouton_chercher' => 'Buscar',
 'bouton_choisir' => 'Escollir',
-'bouton_download' => 'Baixar',
+'bouton_download' => 'Descarregar',
 'bouton_enregistrer' => 'Enregistrar',
 'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la missatgeria interna',
 'bouton_radio_envoi_annonces' => 'Enviar els anuncis editorials',
@@ -643,7 +643,6 @@ Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat pr
 'onglet_repartition_rubrique' => 'Distribuci&oacute; per seccions',
 'onglet_save_restaur_base' => 'C&ograve;pia de seguretat/restaurar base de dades',
 'onglet_vider_cache' => 'Buidar la mem&ograve;ria cau',
-'ortho_trop_de_fautes2' => 'Comenceu per corregir les errades m&eacute;s evidents i torneu-ho a provar.',
 
 // P
 'pass_choix_pass' => 'Escolliu la vostra nova contrasenya:',
