@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -656,7 +656,6 @@ dann out navigat&egrave;r &eacute;',
 'onglet_repartition_rubrique' => 'Partaz sanm rubrik',
 'onglet_save_restaur_base' => 'Sovgard/rosarz l&eacute;ta labaz',
 'onglet_vider_cache' => 'D&eacute;vid lo kas',
-'ortho_trop_de_fautes2' => 'Koriz avann out grogrinn larlik &egrave;k out grafi, apr&eacute;sa ou sra pou es&egrave;y diksyon&egrave;r-la.',
 
 // P
 'pass_choix_pass' => 'Mersi swazi out nouvo modpas :',
