@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -576,7 +576,7 @@ Thank you for your participation!
 'lien_afficher_texte_icones' => 'Show icons and text',
 'lien_afficher_texte_seul' => 'Show text only',
 'lien_liberer' => 'release',
-'lien_liberer_tous' => 'free these articles',
+'lien_liberer_tous' => 'release these articles',
 'lien_nouvea_pense_bete' => 'NEW MEMO',
 'lien_nouveau_message' => 'NEW MESSAGE',
 'lien_nouvelle_annonce' => 'NEW ANNOUNCEMENT',
@@ -651,7 +651,6 @@ Thank you for your participation!
 'onglet_repartition_rubrique' => 'Distribution by section',
 'onglet_save_restaur_base' => 'Backup/restore the database',
 'onglet_vider_cache' => 'Empty the cache',
-'ortho_trop_de_fautes2' => 'Start by correcting the most obvious mistakes, then try again.',
 
 // P
 'pass_choix_pass' => 'Please choose your new password:',
