@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -75,7 +75,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'bouton_radio_non_envoi_annonces' => 'No enviar anuncios',
 'bouton_radio_non_envoi_liste_nouveautes' => 'No enviar la lista de novedades',
 'bouton_recharger_page' => 'Actualizar esta p&aacute;gina',
-'bouton_telecharger' => 'Subir',
+'bouton_telecharger' => 'Descargar',
 'bouton_valider' => 'Validar',
 
 // C
@@ -553,7 +553,7 @@ se puede activar o desactivar .',
 'info_symbole_vert' => 'El s&iacute;mbolo <b>verde</b> indica los  <b>mensajes intercambiados con otras personas</b> del sitio.',
 'info_syndication' => 'sindicaci&oacute;n:',
 'info_syndication_articles' => 'art&iacute;culo(s)',
-'info_telecharger' => 'Subir desde tu ordenador:',
+'info_telecharger' => 'Subir desde tu equipo:',
 'info_telecharger_nouveau_logo' => 'Subir un nuevo logotipo:',
 'info_telecharger_ordinateur' => 'Subir desde tu ordenador:',
 'info_tous_resultats_enregistres' => '[todos los resultados son registrados]',
@@ -651,7 +651,6 @@ se puede activar o desactivar .',
 'onglet_repartition_rubrique' => 'Reparto por secciones',
 'onglet_save_restaur_base' => 'Copia de respaldo y restauraci&oacute;n de la base',
 'onglet_vider_cache' => 'Vaciar la cach&eacute;',
-'ortho_trop_de_fautes2' => 'Comienza por corregir las faltas m&aacute;s evidentes y vuelve a intentarlo.',
 
 // P
 'pass_choix_pass' => 'Elije tu nueva contrase&ntilde;a:',
