@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -644,7 +644,6 @@ Zure pasahitza sarean atzeman ahal izatea nahi ez baduzu, JavaScript-a aktibatu
 'onglet_repartition_rubrique' => 'Atalkako banaketa ',
 'onglet_save_restaur_base' => 'Segurtasun kopia sortu eta basea berrezarri',
 'onglet_vider_cache' => 'Cachea hustu',
-'ortho_trop_de_fautes2' => 'Akats nabarienak zuzentzen hasi eta saiatu berriro.',
 
 // P
 'pass_choix_pass' => 'pasahitz berria aukeratu:',
