@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -649,7 +649,6 @@ amit kapott. Amennyiben nincs regisztr&aacute;lva, akkor',
 'onglet_repartition_rubrique' => 'Rovat szerinti bont&aacute;s',
 'onglet_save_restaur_base' => 'Adatb&aacute;zis ment&eacute;se/resztaur&aacute;l&aacute;sa',
 'onglet_vider_cache' => 'Cache &uuml;r&iacute;t&eacute;se',
-'ortho_trop_de_fautes2' => 'El&ouml;sz&#337;r jav&iacute;tsa a legegy&eacute;rtelm&#369;bb hib&aacute;kat, majd prob&aacute;lkozzon &uacute;jra.',
 
 // P
 'pass_choix_pass' => 'Legyen sz&iacute;ves v&aacute;lasztani az &uacute;j jelszav&aacute;t :',
