@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -568,7 +568,7 @@ o contatta il tuo hoster.</font>',
 'info_visites' => 'visite:',
 'info_vos_rendez_vous' => 'I tuoi prossimi appuntamenti',
 'info_zoom' => 'zoom',
-'infos_vos_pense_bete' => 'I tuoi memo', # MODIF
+'infos_vos_pense_bete' => 'I tuoi memo',
 'item_breve_proposee' => 'Breve proposta',
 
 // L
@@ -650,7 +650,6 @@ devi attivare Javascript nel tuo browser e',
 'onglet_repartition_rubrique' => 'Ripartizione per rubriche',
 'onglet_save_restaur_base' => 'Salva/ripristina il database',
 'onglet_vider_cache' => 'Svuota la cache',
-'ortho_trop_de_fautes2' => 'Correggere gli errori pi&ugrave; evidenti e ricontrollare il testo in un secondo tempo.',
 
 // P
 'pass_choix_pass' => 'Inserisci una nuova password:',
