@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -655,7 +655,6 @@ Bedankt voor je deelname
 'onglet_repartition_rubrique' => 'Verdeling per rubriek',
 'onglet_save_restaur_base' => 'Backup/terugzetten van de databank',
 'onglet_vider_cache' => 'Cache leegmaken',
-'ortho_trop_de_fautes2' => 'Begin met het verbeteren van de meest zichtbare fouten en probeer vervolgens opnieuw.',
 
 // P
 'pass_choix_pass' => 'Kies je nieuwe paswoord:',
