@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -650,7 +650,6 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'onglet_repartition_rubrique' => 'Reparticion per rubricas',
 'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
 'onglet_vider_cache' => 'Vueidar l\'esconeder',
-'ortho_trop_de_fautes2' => 'Comen&ccedil;atz per corregir las errors mei evidentas e tornatz ensajar puish.',
 
 // P
 'pass_choix_pass' => 'Volhatz causir lo v&ograve;ste mot de santa Clara nav&egrave;th:',
