@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -652,7 +652,6 @@ Merc&eacute;s per v&ograve;stra participacion
 'onglet_repartition_rubrique' => 'Reparticion per rubricas',
 'onglet_save_restaur_base' => 'Salvagardar/restaurar la basa',
 'onglet_vider_cache' => 'Vojar l\'escondedor',
-'ortho_trop_de_fautes2' => 'Comen&ccedil;atz per corregir las errors mai evidentas e tornatz assajar pu&egrave;i.',
 
 // P
 'pass_choix_pass' => 'Volgatz causir v&ograve;stre mot de santa Clara nov&egrave;l:',
