@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -652,7 +652,6 @@ Merc&eacute; de la voastra participacion
 'onglet_repartition_rubrique' => 'Reparticion per rubricas',
 'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
 'onglet_vider_cache' => 'Vuar l\'amagador',
-'ortho_trop_de_fautes2' => 'Comen&ccedil;atz per corregir li errors mai evidenti e tornatz assajar pu&egrave;i.',
 
 // P
 'pass_choix_pass' => 'Vorgatz chausir lo voastre nov&egrave;u m&ograve;t de santa Clara&nbsp;:',
