@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -653,7 +653,6 @@ Dzi&#281;kujemy za wzi&#281;cie udzia&#322;u.
 'onglet_repartition_rubrique' => 'Roz&#322;o&#380;enie dzia&#322;&oacute;w',
 'onglet_save_restaur_base' => 'Backup/zapisywanie bazy danych',
 'onglet_vider_cache' => 'Opr&oacute;&#380;nij cache',
-'ortho_trop_de_fautes2' => 'Zacznij od usuni&#281;cia najbardziej oczywistych b&#322;&#281;d&oacute;w i spr&oacute;buj powt&oacute;rnie.',
 
 // P
 'pass_choix_pass' => 'Prosz&#281; wybra&#263; swoje nowe has&#322;o:',
