@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -652,7 +652,6 @@ entre os participantes do s&iacute;tio. Pode activar ou
 'onglet_repartition_rubrique' => 'Distribui&ccedil;&atilde;o das rubricas',
 'onglet_save_restaur_base' => 'Salvaguardar/restaurar a base',
 'onglet_vider_cache' => 'Esvaziar a cache',
-'ortho_trop_de_fautes2' => 'Comece por corrigir os erros mais &oacute;bvios e tente novamente.',
 
 // P
 'pass_choix_pass' => 'Favor escolher a sua nova palavra-passe',
