@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -641,7 +641,6 @@ Se voc&ecirc; n&atilde;o quiser que a sua senha possa ser interceptada na rede,
 'onglet_repartition_rubrique' => 'Reparti&ccedil;&atilde;o por se&ccedil;&otilde;es',
 'onglet_save_restaur_base' => 'Fazer c&oacute;pia de seguran&ccedil;a/restaurar a base',
 'onglet_vider_cache' => 'Esvaziar o cache',
-'ortho_trop_de_fautes2' => 'Comece corrigindo os erros mais &oacute;bvios e tente novamente.',
 
 // P
 'pass_choix_pass' => 'Por favor, escolha a sua nova senha:',
