@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -651,7 +651,6 @@ Mul&#355;umim pentru participarea dumneavoastr&#259;
 'onglet_repartition_rubrique' => 'Reparti&#355;ia pe rubrici',
 'onglet_save_restaur_base' => 'Salva&#355;i/restaura&#355;i baza de date',
 'onglet_vider_cache' => 'Goli&#355;i memoria tampon',
-'ortho_trop_de_fautes2' => '&Icirc;ncepe&#355;i prin a corecta erorile cele mai evidente &#351;i re-&icirc;ncerca&#355;i dup&#259; aceea.',
 
 // P
 'pass_choix_pass' => 'V&#259; rug&#259;m s&#259; alege&#355;i noua dumneavoastr&#259; parol&#259; :',
