@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -642,7 +642,6 @@ Tack f&ouml;r ditt deltagande
 'onglet_repartition_rubrique' => 'F&ouml;rdelning efter avdelning',
 'onglet_save_restaur_base' => 'Backup/&aring;terst&auml;llande av databas',
 'onglet_vider_cache' => 'T&ouml;m cachen',
-'ortho_trop_de_fautes2' => 'B&ouml;rja genom att r&auml;tta de mest uppenbara misstagen och f&ouml;rs&ouml;k igen.',
 
 // P
 'pass_choix_pass' => 'Var v&auml;nlig, v&auml;lj ett nytt l&ouml;senord:',
