@@ -38,7 +38,7 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 
 	// fond demande dans l'url par page=xxxx ?
 	else if (isset($_GET[_SPIP_PAGE])) {
-		$fond = $_GET[_SPIP_PAGE];
+		$fond = (string)$_GET[_SPIP_PAGE];
 
 		// Securite
 		if (strstr($fond, '/')
@@ -121,11 +121,13 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 	// type tableau pour y mettre des choses au besoin.
 	$debug = ((_request('var_mode') == 'debug') OR $tableau_des_temps) ? array(1) : array();
 
-	// Mettre le Content-Type Html si manquant ou debug
+	// Mettre le Content-Type Html si manquant 
+	// Idem si debug, avec retrait du Content-Diposition pour voir le voir
 
 	if ($debug OR !isset($page['entetes']['Content-Type'])) {
 		$page['entetes']['Content-Type'] = 
 			"text/html; charset=" . $GLOBALS['meta']['charset'];
+		if ($debug) unset($page['entetes']['Content-Disposition']);
 		$html = true;
 	} else {
 		$html = preg_match(',^\s*text/html,',$page['entetes']['Content-Type']);
@@ -210,6 +212,8 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 	// (c'est ici qu'on fait var_recherche, validation, boutons d'admin,
 	// cf. public/assembler.php)
 	echo pipeline('affichage_final', $page['texte']);
+
+	if ($lang) lang_select();
 	// l'affichage de la page a pu lever des erreurs (inclusion manquante)
 	// il faut tester a nouveau
 	$debug = ((_request('var_mode') == 'debug') OR $tableau_des_temps) ? array(1) : array();
