@@ -3,13 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 /*
  * Des fonctions pour les requetes SQL
@@ -26,12 +27,14 @@ function _sqlite_init_functions(&$sqlite){
 	
 	$fonctions = array(
 		'CONCAT'		=> array( '_sqlite_func_concat'			,2),
+		'CEIL'      => array( '_sqlite_func_ceil', 1), // absent de sqlite2
 		
 		'DATE_FORMAT'	=> array( '_sqlite_func_strftime'		,2),
 		'DAYOFMONTH'	=> array( '_sqlite_func_dayofmonth'		,1),
 		
 		'EXP'			=> array( 'exp'							,1),//exponentielle
 		'FIND_IN_SET'	=> array( '_sqlite_func_find_in_set'	,2),
+		'FLOOR'      => array( '_sqlite_func_floor', 1), // absent de sqlite2
 
 		'IF'			=> array( '_sqlite_func_if' 			,3),
 		'INSERT'		=> array( '_sqlite_func_insert'			,4),		
@@ -99,6 +102,10 @@ function _sqlite_add_function(&$sqlite, &$f, &$r){
 // entre autre auteurs : mlebas
 //
 
+function _sqlite_func_ceil($a) {
+	return ceil($a);
+}
+
 // http://doc.spip.org/@_sqlite_func_concat
 function _sqlite_func_concat ($a, $b) {
     return $a.$b;
@@ -128,6 +135,9 @@ function _sqlite_func_find_in_set($num, $set) {
   return 0;
 }
 
+function _sqlite_func_floor($a) {
+	return floor($a);
+}
 
 // http://doc.spip.org/@_sqlite_func_if
 function _sqlite_func_if ($bool, $oui, $non) {
@@ -157,12 +167,8 @@ function _sqlite_func_instr ($s, $search) {
 
 // http://doc.spip.org/@_sqlite_func_least
 function _sqlite_func_least () {
-	$numargs = func_num_args();
 	$arg_list = func_get_args();
-	$least=$arg_list[0];
-	for ($i = 0; $i < $numargs; $i++) {
-		if ($arg_list[$i] < $least) $least=$arg_list[$i];
-	}
+    $least = min($arg_list);
 	#spip_log("Passage avec LEAST : $least",'debug');
 	return $least;
 }
@@ -224,9 +230,16 @@ function _sqlite_func_strftime($date, $conv){
 	return strftime($conv, $date);	
 }
 
-// http://doc.spip.org/@_sqlite_func_to_days
+/**
+ * Nombre de jour entre 0000-00-00 et $d
+ * http://doc.spip.org/@_sqlite_func_to_days
+ * cf http://dev.mysql.com/doc/refman/5.5/en/date-and-time-functions.html#function_to-days
+ * @param string $d
+ * @return int
+ */
 function _sqlite_func_to_days ($d) {
-	$result = date("z", _sqlite_func_unix_timestamp($d));
+    $offset = 719528; // nb de jour entre 0000-00-00 et timestamp 0=1970-01-01
+	$result = $offset+(int)ceil(_sqlite_func_unix_timestamp($d)/(24*3600));
 	#spip_log("Passage avec TO_DAYS : $d, $result",'debug');
 	return $result;
 }
@@ -237,9 +250,10 @@ function _sqlite_func_unix_timestamp($d) {
 	//2005-12-02 20:53:53
 	#spip_log("Passage avec UNIX_TIMESTAMP : $d",'debug');
 	// mktime ( [int hour [, int minute [, int second [, int month [, int day [, int year [, int is_dst]]]]]]] )
-    if (!$d) return mktime();
-    preg_match(";^([0-9]{4})-([0-9]+)-([0-9]+) ([0-9]+):([0-9]+):([0-9]+).*$;", $d, $f);
-    return mktime($f[4],$f[5],$f[6],$f[2],$f[3],$f[1]);
+	if (!$d) return mktime();
+	return strtotime($d);
+	#preg_match(";^([0-9]{4})-([0-9]+)-([0-9]+)\s*(?:([0-9]+)(?::([0-9]+)(?::([0-9]+))?)?)?;", $d, $f);
+	#return mktime($f[4],$f[5],$f[6],$f[2],$f[3],$f[1]);
 }
 
 
