@@ -32,7 +32,7 @@ if(!jQuery.load_handlers) {
 				params = null;
 			}
 		}
-		var callback2 = function(res,status) {triggerAjaxLoad(this);callback(res,status);};
+		var callback2 = function(res,status) {triggerAjaxLoad(this);callback.call(this,res,status);};
 
 		return this._ACBload( url, params, callback2 );
 	};
@@ -40,16 +40,18 @@ if(!jQuery.load_handlers) {
 	jQuery._ACBajax = jQuery.ajax;
 
 	jQuery.ajax = function(type) {
+		var s = jQuery.extend(true, {}, jQuery.ajaxSettings, type);
+		var callbackContext = s.context || s;
 		//If called by _load exit now because the callback has already been set
 		if (jQuery.ajax.caller==jQuery.fn._load) return jQuery._ACBajax( type);
-			var orig_complete = type.complete || function() {};
+			var orig_complete = s.complete || function() {};
 			type.complete = function(res,status) {
 				// Do not fire OnAjaxLoad if the dataType is not html
 				var dataType = type.dataType;
 				var ct = (res && (typeof res.getResponseHeader == 'function'))
 					? res.getResponseHeader("content-type"): '';
 				var xml = !dataType && ct && ct.indexOf("xml") >= 0;
-				orig_complete(res,status);
+				orig_complete.call( callbackContext, res, status);
 				if(!dataType && !xml || dataType == "html") triggerAjaxLoad(document);
 		};
 		return jQuery._ACBajax(type);
@@ -72,7 +74,7 @@ jQuery.fn.animeajax = function(end) {
 // le bloc cible en haut de l'ecran
 // si force = true, scroller dans tous les cas
 jQuery.fn.positionner = function(force) {
-	var offset = jQuery(this).offset({'scroll':false});
+	var offset = jQuery(this).offset();
 	var hauteur = parseInt(jQuery(this).css('height'));
 	var scrolltop = self['pageYOffset'] ||
 		jQuery.boxModel && document.documentElement[ 'scrollTop' ] ||
@@ -159,13 +161,16 @@ jQuery.fn.formulaire_dyn_ajax = function(target) {
 					.removeClass('loading')
 					.html(c);
 					var a = jQuery('a:first',recu).eq(0);
-					if (a.length && a.is('a[name=ajax_ancre]')){
+					if (a.length 
+					  && a.is('a[name=ajax_ancre]')
+					  && jQuery(a.attr('href'),cible).length){
 						a = a.attr('href');
-						setTimeout(function(){
+						if (jQuery(a,cible).length)
+							setTimeout(function(){
 							jQuery(a,cible).positionner(true);
 							//a = a.split('#');
 							//window.location.hash = a[1];
-						},10);
+							},10);
 					}
 					else{
 						jQuery(cible).positionner(false);
@@ -222,9 +227,10 @@ jQuery.fn.ajaxbloc = function() {
 			.html(c)
 			.removeClass('loading');
 			var a = jQuery('a:first',jQuery(blocfrag)).eq(0);
-			if (a.length && a.is('a[name=ajax_ancre]')
-			){
-				a = a.attr('href');
+			if (a.length 
+			  && a.is('a[name=ajax_ancre]')
+			  && jQuery(a.attr('href'),blocfrag).length){
+			  	a = a.attr('href')
 				setTimeout(function(){
 					jQuery(a,blocfrag).positionner(true);
 					//a = a.split('#');
